Index: vm/ast.cc |
=================================================================== |
--- vm/ast.cc (revision 13564) |
+++ vm/ast.cc (working copy) |
@@ -286,8 +286,8 @@ |
const Instance* ClosureNode::EvalConstExpr() const { |
if (function().IsImplicitStaticClosureFunction()) { |
- // Return a value that represents a closure. Only the type is relevant. |
- return &Closure::Handle(); |
+ // Return a value that represents an instance. Only the type is relevant. |
+ return &Instance::Handle(); |
} |
return NULL; |
} |